/**
 * Database Migration API
 * Use the Oracle Cloud Infrastructure Database Migration APIs to perform database migration operations.
 * OpenAPI spec version: 20210929
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2022, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import common = require("oci-common");
import * as requests from "./request";
import * as responses from "./response";
import { DatabaseMigrationWaiter } from "./databasemigration-waiter";
export declare enum DatabaseMigrationApiKeys {
}
/**
 * This service client uses {@link common.CircuitBreaker.DefaultConfiguration} for all the operations by default if no circuit breaker configuration is defined by the user.
 */
export declare class DatabaseMigrationClient {
    protected static serviceEndpointTemplate: string;
    protected static endpointServiceName: string;
    protected "_endpoint": string;
    protected "_defaultHeaders": any;
    protected "_waiters": DatabaseMigrationWaiter;
    protected "_clientConfiguration": common.ClientConfiguration;
    protected _circuitBreaker: null;
    protected _httpOptions: any;
    targetService: string;
    protected _httpClient: common.HttpClient;
    constructor(params: common.AuthParams, clientConfiguration?: common.ClientConfiguration);
    /**
     * Get the endpoint that is being used to call (ex, https://www.example.com).
     */
    get endpoint(): string;
    /**
     * Sets the endpoint to call (ex, https://www.example.com).
     * @param endpoint The endpoint of the service.
     */
    set endpoint(endpoint: string);
    get logger(): import("oci-common/lib/log").Logger;
    /**
     * Sets the region to call (ex, Region.US_PHOENIX_1).
     * Note, this will call {@link #endpoint(String) endpoint} after resolving the endpoint.
     * @param region The region of the service.
     */
    set region(region: common.Region);
    /**
     * Sets the regionId to call (ex, 'us-phoenix-1').
     *
     * Note, this will first try to map the region ID to a known Region and call {@link #region(Region) region}.
     * If no known Region could be determined, it will create an endpoint assuming its in default Realm OC1
     * and then call {@link #endpoint(String) endpoint}.
     * @param regionId The public region ID.
     */
    set regionId(regionId: string);
    /**
     * Creates a new DatabaseMigrationWaiter for resources for this service.
     *
     * @param config The waiter configuration for termination and delay strategy
     * @return The service waiters.
     */
    createWaiters(config?: common.WaiterConfiguration): DatabaseMigrationWaiter;
    /**
     * Gets the waiters available for resources for this service.
     *
     * @return The service waiters.
     */
    getWaiters(): DatabaseMigrationWaiter;
    /**
     * Aborts a Migration Job (either Evaluation or Migration).
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param AbortJobRequest
     * @return AbortJobResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.35.1/databasemigration/AbortJob.ts.html |here} to see how to use AbortJob API.
     */
    abortJob(abortJobRequest: requests.AbortJobRequest): Promise<responses.AbortJobResponse>;
    /**
     * Add excluded/included object to the list.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param AddMigrationObjectsRequest
     * @return AddMigrationObjectsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.35.1/databasemigration/AddMigrationObjects.ts.html |here} to see how to use AddMigrationObjects API.
     */
    addMigrationObjects(addMigrationObjectsRequest: requests.AddMigrationObjectsRequest): Promise<responses.AddMigrationObjectsResponse>;
    /**
     * Used to configure an ODMS Agent Compartment ID.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ChangeAgentCompartmentRequest
     * @return ChangeAgentCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.35.1/databasemigration/ChangeAgentCompartment.ts.html |here} to see how to use ChangeAgentCompartment API.
     */
    changeAgentCompartment(changeAgentCompartmentRequest: requests.ChangeAgentCompartmentRequest): Promise<responses.ChangeAgentCompartmentResponse>;
    /**
     * Used to change the Database Connection compartment.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ChangeConnectionCompartmentRequest
     * @return ChangeConnectionCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.35.1/databasemigration/ChangeConnectionCompartment.ts.html |here} to see how to use ChangeConnectionCompartment API.
     */
    changeConnectionCompartment(changeConnectionCompartmentRequest: requests.ChangeConnectionCompartmentRequest): Promise<responses.ChangeConnectionCompartmentResponse>;
    /**
     * Used to change the Migration compartment.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ChangeMigrationCompartmentRequest
     * @return ChangeMigrationCompartmentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.35.1/databasemigration/ChangeMigrationCompartment.ts.html |here} to see how to use ChangeMigrationCompartment API.
     */
    changeMigrationCompartment(changeMigrationCompartmentRequest: requests.ChangeMigrationCompartmentRequest): Promise<responses.ChangeMigrationCompartmentResponse>;
    /**
     * Clone a configuration from an existing Migration.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CloneMigrationRequest
     * @return CloneMigrationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.35.1/databasemigration/CloneMigration.ts.html |here} to see how to use CloneMigration API.
     */
    cloneMigration(cloneMigrationRequest: requests.CloneMigrationRequest): Promise<responses.CloneMigrationResponse>;
    /**
     * Create a Database Connection resource that contains the details to connect to either a Source or Target Database
     * in the migration.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateConnectionRequest
     * @return CreateConnectionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.35.1/databasemigration/CreateConnection.ts.html |here} to see how to use CreateConnection API.
     */
    createConnection(createConnectionRequest: requests.CreateConnectionRequest): Promise<responses.CreateConnectionResponse>;
    /**
     * Create a Migration resource that contains all the details to perform the
     * database migration operation, such as source and destination database
     * details, credentials, etc.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param CreateMigrationRequest
     * @return CreateMigrationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.35.1/databasemigration/CreateMigration.ts.html |here} to see how to use CreateMigration API.
     */
    createMigration(createMigrationRequest: requests.CreateMigrationRequest): Promise<responses.CreateMigrationResponse>;
    /**
     * Delete the ODMS Agent represented by the specified ODMS Agent ID.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteAgentRequest
     * @return DeleteAgentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.35.1/databasemigration/DeleteAgent.ts.html |here} to see how to use DeleteAgent API.
     */
    deleteAgent(deleteAgentRequest: requests.DeleteAgentRequest): Promise<responses.DeleteAgentResponse>;
    /**
     * Deletes the Database Connection represented by the specified connection ID.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteConnectionRequest
     * @return DeleteConnectionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.35.1/databasemigration/DeleteConnection.ts.html |here} to see how to use DeleteConnection API.
     */
    deleteConnection(deleteConnectionRequest: requests.DeleteConnectionRequest): Promise<responses.DeleteConnectionResponse>;
    /**
     * Deletes the migration job represented by the given job ID.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteJobRequest
     * @return DeleteJobResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.35.1/databasemigration/DeleteJob.ts.html |here} to see how to use DeleteJob API.
     */
    deleteJob(deleteJobRequest: requests.DeleteJobRequest): Promise<responses.DeleteJobResponse>;
    /**
     * Deletes the Migration represented by the specified migration ID.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param DeleteMigrationRequest
     * @return DeleteMigrationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.35.1/databasemigration/DeleteMigration.ts.html |here} to see how to use DeleteMigration API.
     */
    deleteMigration(deleteMigrationRequest: requests.DeleteMigrationRequest): Promise<responses.DeleteMigrationResponse>;
    /**
     * Start Validate Migration job.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param EvaluateMigrationRequest
     * @return EvaluateMigrationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.35.1/databasemigration/EvaluateMigration.ts.html |here} to see how to use EvaluateMigration API.
     */
    evaluateMigration(evaluateMigrationRequest: requests.EvaluateMigrationRequest): Promise<responses.EvaluateMigrationResponse>;
    /**
     * Get the Pre-Migration Advisor report details
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetAdvisorReportRequest
     * @return GetAdvisorReportResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.35.1/databasemigration/GetAdvisorReport.ts.html |here} to see how to use GetAdvisorReport API.
     */
    getAdvisorReport(getAdvisorReportRequest: requests.GetAdvisorReportRequest): Promise<responses.GetAdvisorReportResponse>;
    /**
     * Display the ODMS Agent configuration.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetAgentRequest
     * @return GetAgentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.35.1/databasemigration/GetAgent.ts.html |here} to see how to use GetAgent API.
     */
    getAgent(getAgentRequest: requests.GetAgentRequest): Promise<responses.GetAgentResponse>;
    /**
     * Display Database Connection details.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetConnectionRequest
     * @return GetConnectionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.35.1/databasemigration/GetConnection.ts.html |here} to see how to use GetConnection API.
     */
    getConnection(getConnectionRequest: requests.GetConnectionRequest): Promise<responses.GetConnectionResponse>;
    /**
     * Get a migration job.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetJobRequest
     * @return GetJobResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.35.1/databasemigration/GetJob.ts.html |here} to see how to use GetJob API.
     */
    getJob(getJobRequest: requests.GetJobRequest): Promise<responses.GetJobResponse>;
    /**
     * Get the migration Job Output content as a String.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetJobOutputContentRequest
     * @return GetJobOutputContentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.35.1/databasemigration/GetJobOutputContent.ts.html |here} to see how to use GetJobOutputContent API.
     */
    getJobOutputContent(getJobOutputContentRequest: requests.GetJobOutputContentRequest): Promise<responses.GetJobOutputContentResponse>;
    /**
     * Display Migration details.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetMigrationRequest
     * @return GetMigrationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.35.1/databasemigration/GetMigration.ts.html |here} to see how to use GetMigration API.
     */
    getMigration(getMigrationRequest: requests.GetMigrationRequest): Promise<responses.GetMigrationResponse>;
    /**
     * Gets the details of a work request.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param GetWorkRequestRequest
     * @return GetWorkRequestResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.35.1/databasemigration/GetWorkRequest.ts.html |here} to see how to use GetWorkRequest API.
     */
    getWorkRequest(getWorkRequestRequest: requests.GetWorkRequestRequest): Promise<responses.GetWorkRequestResponse>;
    /**
     * Get details of the ODMS Agent Images available to install on-premises.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListAgentImagesRequest
     * @return ListAgentImagesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.35.1/databasemigration/ListAgentImages.ts.html |here} to see how to use ListAgentImages API.
     */
    listAgentImages(listAgentImagesRequest: requests.ListAgentImagesRequest): Promise<responses.ListAgentImagesResponse>;
    /**
     * Display the name of all the existing ODMS Agents in the server.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListAgentsRequest
     * @return ListAgentsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.35.1/databasemigration/ListAgents.ts.html |here} to see how to use ListAgents API.
     */
    listAgents(listAgentsRequest: requests.ListAgentsRequest): Promise<responses.ListAgentsResponse>;
    /**
     * List all Database Connections.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListConnectionsRequest
     * @return ListConnectionsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.35.1/databasemigration/ListConnections.ts.html |here} to see how to use ListConnections API.
     */
    listConnections(listConnectionsRequest: requests.ListConnectionsRequest): Promise<responses.ListConnectionsResponse>;
    /**
     * List the excluded database objects.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListExcludedObjectsRequest
     * @return ListExcludedObjectsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.35.1/databasemigration/ListExcludedObjects.ts.html |here} to see how to use ListExcludedObjects API.
     */
    listExcludedObjects(listExcludedObjectsRequest: requests.ListExcludedObjectsRequest): Promise<responses.ListExcludedObjectsResponse>;
    /**
     * List the Job Outputs
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListJobOutputsRequest
     * @return ListJobOutputsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.35.1/databasemigration/ListJobOutputs.ts.html |here} to see how to use ListJobOutputs API.
     */
    listJobOutputs(listJobOutputsRequest: requests.ListJobOutputsRequest): Promise<responses.ListJobOutputsResponse>;
    /**
     * List all the names of the Migration jobs associated to the specified
     * migration site.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListJobsRequest
     * @return ListJobsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.35.1/databasemigration/ListJobs.ts.html |here} to see how to use ListJobs API.
     */
    listJobs(listJobsRequest: requests.ListJobsRequest): Promise<responses.ListJobsResponse>;
    /**
     * Display sample object types to exclude or include for a Migration.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListMigrationObjectTypesRequest
     * @return ListMigrationObjectTypesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.35.1/databasemigration/ListMigrationObjectTypes.ts.html |here} to see how to use ListMigrationObjectTypes API.
     */
    listMigrationObjectTypes(listMigrationObjectTypesRequest: requests.ListMigrationObjectTypesRequest): Promise<responses.ListMigrationObjectTypesResponse>;
    /**
     * Display excluded/included objects.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListMigrationObjectsRequest
     * @return ListMigrationObjectsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.35.1/databasemigration/ListMigrationObjects.ts.html |here} to see how to use ListMigrationObjects API.
     */
    listMigrationObjects(listMigrationObjectsRequest: requests.ListMigrationObjectsRequest): Promise<responses.ListMigrationObjectsResponse>;
    /**
     * List all Migrations.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListMigrationsRequest
     * @return ListMigrationsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.35.1/databasemigration/ListMigrations.ts.html |here} to see how to use ListMigrations API.
     */
    listMigrations(listMigrationsRequest: requests.ListMigrationsRequest): Promise<responses.ListMigrationsResponse>;
    /**
     * Gets the errors for a work request.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListWorkRequestErrorsRequest
     * @return ListWorkRequestErrorsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.35.1/databasemigration/ListWorkRequestErrors.ts.html |here} to see how to use ListWorkRequestErrors API.
     */
    listWorkRequestErrors(listWorkRequestErrorsRequest: requests.ListWorkRequestErrorsRequest): Promise<responses.ListWorkRequestErrorsResponse>;
    /**
     * Gets the logs for a work request.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListWorkRequestLogsRequest
     * @return ListWorkRequestLogsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.35.1/databasemigration/ListWorkRequestLogs.ts.html |here} to see how to use ListWorkRequestLogs API.
     */
    listWorkRequestLogs(listWorkRequestLogsRequest: requests.ListWorkRequestLogsRequest): Promise<responses.ListWorkRequestLogsResponse>;
    /**
     * Lists the work requests in a compartment or for a specified resource.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ListWorkRequestsRequest
     * @return ListWorkRequestsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.35.1/databasemigration/ListWorkRequests.ts.html |here} to see how to use ListWorkRequests API.
     */
    listWorkRequests(listWorkRequestsRequest: requests.ListWorkRequestsRequest): Promise<responses.ListWorkRequestsResponse>;
    /**
     * Remove excluded/included objects.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param RemoveMigrationObjectsRequest
     * @return RemoveMigrationObjectsResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.35.1/databasemigration/RemoveMigrationObjects.ts.html |here} to see how to use RemoveMigrationObjects API.
     */
    removeMigrationObjects(removeMigrationObjectsRequest: requests.RemoveMigrationObjectsRequest): Promise<responses.RemoveMigrationObjectsResponse>;
    /**
     * Resume a migration Job.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param ResumeJobRequest
     * @return ResumeJobResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.35.1/databasemigration/ResumeJob.ts.html |here} to see how to use ResumeJob API.
     */
    resumeJob(resumeJobRequest: requests.ResumeJobRequest): Promise<responses.ResumeJobResponse>;
    /**
     * Display Migration Phases for a specified migration.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param RetrieveSupportedPhasesRequest
     * @return RetrieveSupportedPhasesResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.35.1/databasemigration/RetrieveSupportedPhases.ts.html |here} to see how to use RetrieveSupportedPhases API.
     */
    retrieveSupportedPhases(retrieveSupportedPhasesRequest: requests.RetrieveSupportedPhasesRequest): Promise<responses.RetrieveSupportedPhasesResponse>;
    /**
     * Start Migration job.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param StartMigrationRequest
     * @return StartMigrationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.35.1/databasemigration/StartMigration.ts.html |here} to see how to use StartMigration API.
     */
    startMigration(startMigrationRequest: requests.StartMigrationRequest): Promise<responses.StartMigrationResponse>;
    /**
     * Modifies the ODMS Agent represented by the given ODMS Agent ID.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateAgentRequest
     * @return UpdateAgentResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.35.1/databasemigration/UpdateAgent.ts.html |here} to see how to use UpdateAgent API.
     */
    updateAgent(updateAgentRequest: requests.UpdateAgentRequest): Promise<responses.UpdateAgentResponse>;
    /**
     * Update Database Connection resource details.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateConnectionRequest
     * @return UpdateConnectionResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.35.1/databasemigration/UpdateConnection.ts.html |here} to see how to use UpdateConnection API.
     */
    updateConnection(updateConnectionRequest: requests.UpdateConnectionRequest): Promise<responses.UpdateConnectionResponse>;
    /**
     * Update Migration Job resource details.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateJobRequest
     * @return UpdateJobResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.35.1/databasemigration/UpdateJob.ts.html |here} to see how to use UpdateJob API.
     */
    updateJob(updateJobRequest: requests.UpdateJobRequest): Promise<responses.UpdateJobResponse>;
    /**
     * Update Migration resource details.
     *
     * This operation does not retry by default if the user has not defined a retry configuration.
     * @param UpdateMigrationRequest
     * @return UpdateMigrationResponse
     * @throws OciError when an error occurs
     * @example Click {@link https://docs.cloud.oracle.com/en-us/iaas/tools/typescript-sdk-examples/2.35.1/databasemigration/UpdateMigration.ts.html |here} to see how to use UpdateMigration API.
     */
    updateMigration(updateMigrationRequest: requests.UpdateMigrationRequest): Promise<responses.UpdateMigrationResponse>;
}
