/**
 * Threat Intelligence API
 * Use the Threat Intelligence API to view indicators of compromise and related items. For more information, see [Overview of Threat Intelligence](/Content/ThreatIntelligence/Concepts/threatintelligenceoverview.htm).
 * OpenAPI spec version: 20210831
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2022, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
/**
 * A data signature observed on a network or host that indicates a potential security threat. Indicators can be plain text or computed (hashed) values.
 */
export interface Indicator {
    /**
     * The OCID of the indicator.
     */
    "id": string;
    /**
     * Type of indicator
     */
    "type": model.IndicatorType;
    /**
     * The value for this indicator.
     * Format is dependent upon `type`, e.g. DOMAIN_NAME \"evil.example.com\", MD5_HASH \"44d88612fea8a8f36de82e1278abb02f\", IP_ADDRESS \"2001:db8::1\".
     *
     */
    "value": string;
    /**
     * Confidence is an integer from 0 to 100 that provides a measure of our certainty in the maliciousness of the indicator.  This confidence value is aggregated from the confidence in the threat types, attributes, and relationships to create an overall value for the indicator. Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "confidence"?: number;
    /**
     * Compartment Identifier
     */
    "compartmentId"?: string;
    /**
     * Characteristics of the threat indicator based on previous observations or behavior. May include related tactics, techniques, and procedures.
     */
    "threatTypes": Array<model.ThreatType>;
    /**
     * A map of attribute name (string) to IndicatorAttribute (values and supporting data).
     * This provides generic storage for additional data about an indicator.
     *
     */
    "attributes": Array<model.IndicatorAttribute>;
    /**
     * A map of relationship name (string) to IndicatorRelationship (related entities and supporting data).
     * This provides generic storage for relationships between indicators or other entities.
     *
     */
    "relationships": Array<model.IndicatorRelationship>;
    /**
     * The state of the indicator.  It will always be ACTIVE.  This field is added for consistency.
     */
    "lifecycleState"?: model.LifecycleState;
    /**
     * The time the data was first seen for this indicator. An RFC3339 formatted datetime string
     */
    "timeCreated": Date;
    /**
     * The last time this indicator was updated. It starts with the same value as timeCreated and is never empty. An RFC3339 formatted datetime string
     */
    "timeUpdated": Date;
}
export declare namespace Indicator {
    function getJsonObj(obj: Indicator): object;
    function getDeserializedJsonObj(obj: Indicator): object;
}
